@@ -90,8 +90,8 @@ on_supported_os.reject { |_, f| f[:os]['family'] == 'Solaris' }.each do |os, f|
           context 'when set' do
             let(:params) do
               {
-                servers: %w[a b c d],
-                preferred_servers: %w[a b],
+                servers: ['a', 'b', 'c', 'd'],
+                preferred_servers: ['a', 'b'],
                 iburst_enable: false,
               }
             end
@@ -103,7 +103,7 @@ on_supported_os.reject { |_, f| f[:os]['family'] == 'Solaris' }.each do |os, f|
           context 'when not set' do
             let(:params) do
               {
-                servers: %w[a b c d],
+                servers: ['a', 'b', 'c', 'd'],
                 preferred_servers: [],
               }
             end
@@ -118,8 +118,8 @@ on_supported_os.reject { |_, f| f[:os]['family'] == 'Solaris' }.each do |os, f|
           context 'when set' do
             let(:params) do
               {
-                servers: %w[a b c d],
-                noselect_servers: %w[a b],
+                servers: ['a', 'b', 'c', 'd'],
+                noselect_servers: ['a', 'b'],
                 iburst_enable: false,
               }
             end
@@ -131,7 +131,7 @@ on_supported_os.reject { |_, f| f[:os]['family'] == 'Solaris' }.each do |os, f|
           context 'when not set' do
             let(:params) do
               {
-                servers: %w[a b c d],
+                servers: ['a', 'b', 'c', 'd'],
                 noselect_servers: [],
               }
             end
@@ -145,7 +145,7 @@ on_supported_os.reject { |_, f| f[:os]['family'] == 'Solaris' }.each do |os, f|
           context 'when set' do
             let(:params) do
               {
-                servers: %w[a b c d],
+                servers: ['a', 'b', 'c', 'd'],
                 interfaces: ['127.0.0.1', 'a.b.c.d'],
               }
             end
@@ -157,7 +157,7 @@ on_supported_os.reject { |_, f| f[:os]['family'] == 'Solaris' }.each do |os, f|
           context 'when not set' do
             let(:params) do
               {
-                servers: %w[a b c d],
+                servers: ['a', 'b', 'c', 'd'],
               }
             end
 
@@ -172,7 +172,7 @@ on_supported_os.reject { |_, f| f[:os]['family'] == 'Solaris' }.each do |os, f|
             let(:params) do
               {
                 interfaces: ['a.b.c.d'],
-                interfaces_ignore: %w[wildcard ipv6],
+                interfaces_ignore: ['wildcard', 'ipv6'],
               }
             end
 
@@ -184,7 +184,7 @@ on_supported_os.reject { |_, f| f[:os]['family'] == 'Solaris' }.each do |os, f|
             let(:params) do
               {
                 interfaces: ['127.0.0.1'],
-                servers: %w[a b c d],
+                servers: ['a', 'b', 'c', 'd'],
               }
             end
 
@@ -233,6 +233,9 @@ on_supported_os.reject { |_, f| f[:os]['family'] == 'Solaris' }.each do |os, f|
             it 'contains dhcp file' do
               is_expected.to contain_file('/var/lib/ntp/ntp.conf.dhcp').with_ensure('absent')
             end
+            it 'contains ntp.sh file' do
+              is_expected.to contain_file('/etc/dhcp/dhclient.d/ntp.sh').with_ensure('absent')
+            end
           end
           context 'when set to false' do
             let(:params) do
@@ -395,20 +398,11 @@ on_supported_os.reject { |_, f| f[:os]['family'] == 'Solaris' }.each do |os, f|
         context 'when choosing the default pool servers' do
           case f[:os]['family']
           when 'RedHat'
-            if f[:os]['name'] == 'Fedora'
-              it 'uses the fedora ntp servers' do
-                is_expected.to contain_file('/etc/ntp.conf').with('content' => %r{server \d.fedora.pool.ntp.org})
-              end
-              it do
-                is_expected.to contain_file('/etc/ntp/step-tickers').with('content' => %r{\d.fedora.pool.ntp.org})
-              end
-            else
-              it 'uses the centos ntp servers' do
-                is_expected.to contain_file('/etc/ntp.conf').with('content' => %r{server \d.centos.pool.ntp.org})
-              end
-              it do
-                is_expected.to contain_file('/etc/ntp/step-tickers').with('content' => %r{\d.centos.pool.ntp.org})
-              end
+            it 'uses the centos ntp servers' do
+              is_expected.to contain_file('/etc/ntp.conf').with('content' => %r{server \d.centos.pool.ntp.org})
+            end
+            it do
+              is_expected.to contain_file('/etc/ntp/step-tickers').with('content' => %r{\d.centos.pool.ntp.org})
             end
           when 'Debian'
             it 'uses the debian ntp servers' do
@@ -730,7 +724,7 @@ on_supported_os.reject { |_, f| f[:os]['family'] == 'Solaris' }.each do |os, f|
         context 'when set to true' do
           let(:params) do
             {
-              servers: %w[a b c d],
+              servers: ['a', 'b', 'c', 'd'],
               leapfile: '/etc/leap-seconds.3629404800',
             }
           end
@@ -743,7 +737,7 @@ on_supported_os.reject { |_, f| f[:os]['family'] == 'Solaris' }.each do |os, f|
         context 'when set to false' do
           let(:params) do
             {
-              servers: %w[a b c d],
+              servers: ['a', 'b', 'c', 'd'],
             }
           end
 
@@ -757,7 +751,7 @@ on_supported_os.reject { |_, f| f[:os]['family'] == 'Solaris' }.each do |os, f|
         context 'when set to true' do
           let(:params) do
             {
-              servers: %w[a b c d],
+              servers: ['a', 'b', 'c', 'd'],
               logfile: '/var/log/foobar.log',
             }
           end
@@ -770,7 +764,7 @@ on_supported_os.reject { |_, f| f[:os]['family'] == 'Solaris' }.each do |os, f|
         context 'when set to false' do
           let(:params) do
             {
-              servers: %w[a b c d],
+              servers: ['a', 'b', 'c', 'd'],
             }
           end
 
@@ -784,7 +778,7 @@ on_supported_os.reject { |_, f| f[:os]['family'] == 'Solaris' }.each do |os, f|
         context 'when set to true' do
           let(:params) do
             {
-              servers: %w[a b c d],
+              servers: ['a', 'b', 'c', 'd'],
               ntpsigndsocket: '/usr/local/samba/var/lib/ntp_signd',
             }
           end
@@ -797,7 +791,7 @@ on_supported_os.reject { |_, f| f[:os]['family'] == 'Solaris' }.each do |os, f|
         context 'when set to false' do
           let(:params) do
             {
-              servers: %w[a b c d],
+              servers: ['a', 'b', 'c', 'd'],
             }
           end
 
@@ -811,7 +805,7 @@ on_supported_os.reject { |_, f| f[:os]['family'] == 'Solaris' }.each do |os, f|
         context 'when set to true' do
           let(:params) do
             {
-              servers: %w[a b c d],
+              servers: ['a', 'b', 'c', 'd'],
               authprov: '/opt/novell/xad/lib64/libw32time.so 131072:4294967295 global',
             }
           end
@@ -824,7 +818,7 @@ on_supported_os.reject { |_, f| f[:os]['family'] == 'Solaris' }.each do |os, f|
         context 'when set to false' do
           let(:params) do
             {
-              servers: %w[a b c d],
+              servers: ['a', 'b', 'c', 'd'],
             }
           end
 
@@ -876,7 +870,7 @@ on_supported_os.reject { |_, f| f[:os]['family'] == 'Solaris' }.each do |os, f|
         context 'when set' do
           let(:params) do
             {
-              pool: %w[foo bar],
+              pool: ['foo', 'bar'],
             }
           end
 
@@ -905,7 +899,7 @@ on_supported_os.reject { |_, f| f[:os]['family'] == 'Solaris' }.each do |os, f|
         context 'when set' do
           let(:params) do
             {
-              peers: %w[foo bar],
+              peers: ['foo', 'bar'],
             }
           end
 
